Utility Function to Create an Order on Tremendous. For full API documentation, see https://developers.tremendous.com/reference/core-orders-create.
create_order_body(
recipient_name,
recipient_email = NULL,
recipient_phone = NULL,
reward_amount,
currency_code = "USD",
delivery_method = "EMAIL",
payment_description_id,
funding_source_id,
reward_types
)Name of the recipient.
Email address of the recipient.
Phone number of the recipient (US phone numbers only).
Amount of the reward (numeric).
Currency of the reward (default to "USD").
Default to "EMAIL", for sending the reward to the recipient via email. Alternatively, reward can be delivered via a link ("LINK") or text message ("PHONE").
Unique ID for specific order. This will appear
as external_id on Tremendous Dashboard.
ID of the funding source linked to your account, to
draw funds from for this order. One of the IDs from
trem_get("funding_sources").
A character vector of product ids -- reward options -- for the recipient to choose from. Available options can be found here.
A nested list that, when converted to JSON, is accepted by 'Tremendous' API's create order endpoint.